@@ -643,13 +643,11 @@ class Chat:
         # Only speak/braille the new message if it matches how the user
         # wants chat messages spoken.
         #
+        verbosity = self._script.getSettings().chatMessageVerbosity
         if orca_state.activeScript.name != self._script.name \
-           and settings.chatMessageVerbosity == \
-                settings.CHAT_SPEAK_ALL_IF_FOCUSED:
+           and verbosity == settings.CHAT_SPEAK_ALL_IF_FOCUSED:
             return
-        elif not focused \
-           and settings.chatMessageVerbosity == \
-           settings.CHAT_SPEAK_FOCUSED_CHANNEL:
+        elif not focused and verbosity == settings.CHAT_SPEAK_FOCUSED_CHANNEL:
             return
 
         text = ""
@@ -706,7 +704,7 @@ class Chat:
             #
             return True
 
-        elif self.isTypingStatusChangedEvent(event.source):
+        elif self.isTypingStatusChangedEvent(event):
             self.presentTypingStatusChange(event, event.any_data)
             return True
 
@@ -972,10 +970,8 @@ class Chat:
         - event: the accessible event being examined
         """
 
-        if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent) \
-           and orca_state.lastNonModifierKeyEvent \
-           and (orca_state.lastNonModifierKeyEvent.event_string == "Tab") \
-           and event.any_data and (event.any_data != "\t"):
+        lastKey, mods = self._script.utilities.lastKeyAndModifiers()
+        if lastKey == "Tab" and event.any_data and event.any_data != "\t":
             return True
 
         return False
